# Craftbeerpi4 PushOver Notifications Plugin

## Plugin to forward Craftbeerpi4 Notifications to Pushover Push Notification service

- Installation:

	- Plugin requires cbpi >= 4.1.10.rc2
	- sudo pip3 install cbpi4-PushOver
	- or installation from github


- Usage:

	- First Installation will add parameters to settings.
	- Configure settings by adding token and user.
	- Restart cbpi

- Parameters:

	- pushover_token: your token for this service
	- pushover_user: your user for this service

### Changelog:

- 10.06.23: (0.0.8) bump version to release
- 02.06.23: (0.0.8.rc1) added cbpi4 requirement
- 05.04.23: (0.0.8.a2) test for plugin settings selection test branch
- 10.05.22: (0.0.7) Updated README (removed cbpi add)
- 10.05.22: (0.0.4) Removed cbpi dependency
- 02.04.21:  Minor changes
- 15.03.21: Initial Release.
